/*
 * vcard-parser.h
 *
 * Copyright 2019 Michael Rasmussen <mir@datanom.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef __VCARD_H__
#define __VCARD_H__

#include <glib.h>

G_BEGIN_DECLS

typedef enum {
	// vCard 2.1 properties and up
	N = 0,
	FN,
	PHOTO,
	BDAY,
	ADR,
	LABEL, // Removed in vCard 4.0
	TEL,
	EMAIL,
	MAILER, // Removed in vCard 4.0
	GEO,
	TITLE,
	ROLE,
	LOGO,
	ORG,
	NOTE,
	REV,
	SOUND,
	URL,
	UID,
	VERSION,
	KEY,
	TZ,
	// vCard 3.0 properties
	CATEGORIES,
	SORT_STRING,
	PRODID,
	NICKNAME,
	CLASS, // Removed in vCard 4.0
	// rfc2739 properties
	FBURL,
	CAPURI,
	CALURI,
	CALADRURI,
	// rfc4770 properties
	IMPP,
	// vCard 4.0 properties
	SOURCE,
	XML,
	ANNIVERSARY,
	CLIENTPIDMAP,
	LANG,
	GENDER,
	KIND,
	MEMBER,
	RELATED,
	// rfc6474 properties
	BIRTHPLACE,
	DEATHPLACE,
	DEATHDATE,
	// rfc6715 properties
	EXPERTISE,
	HOBBY,
	INTEREST,
	ORG_DIRECTORY,
	VCARD_PROPERTIES,
} Property;

gchar* Proterties[VCARD_PROPERTIES+1] = {
	"N",
	"FN",
	"PHOTO",
	"BDAY",
	"ADR",
	"LABEL",
	"TEL",
	"EMAIL",
	"MAILER",
	"GEO",
	"TITLE",
	"ROLE",
	"LOGO",
	"ORG",
	"NOTE",
	"REV",
	"SOUND",
	"URL",
	"UID",
	"VERSION",
	"KEY",
	"TZ",
	"CATEGORIES",
	"SORT-STRING",
	"PRODID",
	"NICKNAME",
	"CLASS",
	"FBURL",
	"CAPURI",
	"CALURI",
	"CALADRURI",
	"IMPP",
	"SOURCE",
	"XML",
	"ANNIVERSARY",
	"CLIENTPIDMAP",
	"LANG",
	"GENDER",
	"KIND",
	"MEMBER",
	"RELATED",
	"BIRTHPLACE",
	"DEATHPLACE",
	"DEATHDATE",
	"EXPERTISE",
	"HOBBY",
	"INTEREST",
	"ORG-DIRECTORY",
	NULL
};

G_END_DECLS

gboolean vcard_parse_text();

#endif
